Available Settings — django-dajaxice v0.1.8 documentation

### Navigation

- index
- next |
- previous |
- django-dajaxice v0.1.8 documentation »

# Available Settings

## DAJAXICE_MEDIA_PREFIX

This will be the namespace that dajaxice will use as endpoint.

Defaults to `dajaxice`

Optional: `True`

## DAJAXICE_XMLHTTPREQUEST_JS_IMPORT

Include XmlHttpRequest.js inside dajaxice.core.js

Defaults to `True`

Optional: `True`

## DAJAXICE_JSON2_JS_IMPORT

Include json2.js inside dajaxice.core.js

Defaults to `True`

Optional: `True`

## DAJAXICE_EXCEPTION

Default data sent when an exception occurs.

Defaults to `"DAJAXICE_EXCEPTION"`

Optional: `True`

### Navigation

- index
- next |
- previous |
- django-dajaxice v0.1.8 documentation »